<?php
/**
 * Customizer active callbacks
 *
 * @package Theme Palace
 * @subpackage Myself Pro
 * @since Myself Pro 1.0.0
 */

if ( ! function_exists( 'myself_pro_is_loader_enable' ) ) :
	/**
	 * Check if loader is enabled.
	 *
	 * @since Myself Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function myself_pro_is_loader_enable( $control ) {
		return $control->manager->get_setting( 'myself_pro_theme_options[loader_enable]' )->value();
	}
endif;

if ( ! function_exists( 'myself_pro_is_breadcrumb_enable' ) ) :
	/**
	 * Check if breadcrumb is enabled.
	 *
	 * @since Myself Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function myself_pro_is_breadcrumb_enable( $control ) {
		return $control->manager->get_setting( 'myself_pro_theme_options[breadcrumb_enable]' )->value();
	}
endif;

if ( ! function_exists( 'myself_pro_is_pagination_enable' ) ) :
	/**
	 * Check if pagination is enabled.
	 *
	 * @since Myself Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function myself_pro_is_pagination_enable( $control ) {
		return $control->manager->get_setting( 'myself_pro_theme_options[pagination_enable]' )->value();
	}
endif;

/**
 * Front Page Active Callbacks
 */

/**
 * Check if introduction section is enabled.
 *
 * @since Myself Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function myself_pro_is_introduction_section_enable( $control ) {
	return ( $control->manager->get_setting( 'myself_pro_theme_options[introduction_section_enable]' )->value() );
}

/**
 * Check if introduction section content type is post.
 *
 * @since Myself Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function myself_pro_is_introduction_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'myself_pro_theme_options[introduction_content_type]' )->value();
	return myself_pro_is_introduction_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if introduction section content type is page.
 *
 * @since Myself Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function myself_pro_is_introduction_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'myself_pro_theme_options[introduction_content_type]' )->value();
	return myself_pro_is_introduction_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if introduction section content type is custom.
 *
 * @since Myself Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function myself_pro_is_introduction_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'myself_pro_theme_options[introduction_content_type]' )->value();
	return myself_pro_is_introduction_section_enable( $control ) && ( 'custom' == $content_type );
}

/**
 * Check if about section is enabled.
 *
 * @since Myself Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function myself_pro_is_about_section_enable( $control ) {
	return ( $control->manager->get_setting( 'myself_pro_theme_options[about_section_enable]' )->value() );
}

/**
 * Check if about section content type is post.
 *
 * @since Myself Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function myself_pro_is_about_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'myself_pro_theme_options[about_content_type]' )->value();
	return myself_pro_is_about_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if about section content type is page.
 *
 * @since Myself Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function myself_pro_is_about_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'myself_pro_theme_options[about_content_type]' )->value();
	return myself_pro_is_about_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if about section content type is custom.
 *
 * @since Myself Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function myself_pro_is_about_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'myself_pro_theme_options[about_content_type]' )->value();
	return myself_pro_is_about_section_enable( $control ) && ( 'custom' == $content_type );
}

/**
 * Check if my_profile section is enabled.
 *
 * @since Myself Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function myself_pro_is_my_profile_section_enable( $control ) {
	return ( $control->manager->get_setting( 'myself_pro_theme_options[my_profile_section_enable]' )->value() );
}

/**
 * Check if my_profile section content type is category.
 *
 * @since Myself Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function myself_pro_is_my_profile_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'myself_pro_theme_options[my_profile_content_type]' )->value();
	return myself_pro_is_my_profile_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if my_profile section content type is page.
 *
 * @since Myself Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function myself_pro_is_my_profile_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'myself_pro_theme_options[my_profile_content_type]' )->value();
	return myself_pro_is_my_profile_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if my_profile section content type is post.
 *
 * @since Myself Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function myself_pro_is_my_profile_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'myself_pro_theme_options[my_profile_content_type]' )->value();
	return myself_pro_is_my_profile_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if service section is enabled.
 *
 * @since Myself Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function myself_pro_is_service_section_enable( $control ) {
	return ( $control->manager->get_setting( 'myself_pro_theme_options[service_section_enable]' )->value() );
}

/**
 * Check if experience section is enabled.
 *
 * @since Myself Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function myself_pro_is_experience_section_enable( $control ) {
	return ( $control->manager->get_setting( 'myself_pro_theme_options[experience_section_enable]' )->value() );
}

/**
 * Check if experience section content type is custom.
 *
 * @since Myself Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function myself_pro_is_experience_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'myself_pro_theme_options[experience_content_type]' )->value();
	return myself_pro_is_experience_section_enable( $control ) && ( 'custom' == $content_type );
}

/**
 * Check if experience section content type is page.
 *
 * @since Myself Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function myself_pro_is_experience_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'myself_pro_theme_options[experience_content_type]' )->value();
	return myself_pro_is_experience_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if experience section content type is post.
 *
 * @since Myself Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function myself_pro_is_experience_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'myself_pro_theme_options[experience_content_type]' )->value();
	return myself_pro_is_experience_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if portfolio section is enabled.
 *
 * @since Myself Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function myself_pro_is_portfolio_section_enable( $control ) {
	return ( $control->manager->get_setting( 'myself_pro_theme_options[portfolio_section_enable]' )->value() );
}

/**
 * Check if portfolio section content type is category.
 *
 * @since Myself Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function myself_pro_is_portfolio_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'myself_pro_theme_options[portfolio_content_type]' )->value();
	return myself_pro_is_portfolio_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if portfolio section content type is page.
 *
 * @since Myself Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function myself_pro_is_portfolio_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'myself_pro_theme_options[portfolio_content_type]' )->value();
	return myself_pro_is_portfolio_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if portfolio section content type is post.
 *
 * @since Myself Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function myself_pro_is_portfolio_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'myself_pro_theme_options[portfolio_content_type]' )->value();
	return myself_pro_is_portfolio_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if video section is enabled.
 *
 * @since Myself Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function myself_pro_is_video_section_enable( $control ) {
	return ( $control->manager->get_setting( 'myself_pro_theme_options[video_section_enable]' )->value() );
}

/**
 * Check if clients section is enabled.
 *
 * @since Myself Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function myself_pro_is_clients_section_enable( $control ) {
	return ( $control->manager->get_setting( 'myself_pro_theme_options[clients_section_enable]' )->value() );
}

/**
 * Check if clients section content type is post.
 *
 * @since Myself Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function myself_pro_is_clients_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'myself_pro_theme_options[clients_content_type]' )->value();
	return myself_pro_is_clients_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if clients section content type is page.
 *
 * @since Myself Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function myself_pro_is_clients_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'myself_pro_theme_options[clients_content_type]' )->value();
	return myself_pro_is_clients_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if clients section content type is category.
 *
 * @since Myself Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function myself_pro_is_clients_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'myself_pro_theme_options[clients_content_type]' )->value();
	return myself_pro_is_clients_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if clients section content type is custom.
 *
 * @since Myself Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function myself_pro_is_clients_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'myself_pro_theme_options[clients_content_type]' )->value();
	return myself_pro_is_clients_section_enable( $control ) && ( 'custom' == $content_type );
}

/**
 * Check if testimonial section is enabled.
 *
 * @since Myself Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function myself_pro_is_testimonial_section_enable( $control ) {
	return ( $control->manager->get_setting( 'myself_pro_theme_options[testimonial_section_enable]' )->value() );
}

/**
 * Check if testimonial section seperator.
 *
 * @since Myself Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function myself_pro_is_testimonial_section_content_seperator_enable( $control ) {
	$content_type = $control->manager->get_setting( 'myself_pro_theme_options[testimonial_content_type]' )->value();
	return myself_pro_is_testimonial_section_enable( $control ) && ( 'category' !== $content_type );
}

/**
 * Check if testimonial section content type is post.
 *
 * @since Myself Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function myself_pro_is_testimonial_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'myself_pro_theme_options[testimonial_content_type]' )->value();
	return myself_pro_is_testimonial_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if testimonial section content type is page.
 *
 * @since Myself Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function myself_pro_is_testimonial_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'myself_pro_theme_options[testimonial_content_type]' )->value();
	return myself_pro_is_testimonial_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if testimonial section content type is category.
 *
 * @since Myself Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function myself_pro_is_testimonial_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'myself_pro_theme_options[testimonial_content_type]' )->value();
	return myself_pro_is_testimonial_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if testimonial section content type is position.
 *
 * @since Myself Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function myself_pro_is_testimonial_section_content_position_enable( $control ) {
	$content_type = $control->manager->get_setting( 'myself_pro_theme_options[testimonial_content_type]' )->value();
	return myself_pro_is_testimonial_section_enable( $control ) && ( 'category' !== $content_type );
}

/**
 * Check if testimonial section content type is custom.
 *
 * @since Myself Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function myself_pro_is_testimonial_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'myself_pro_theme_options[testimonial_content_type]' )->value();
	return myself_pro_is_testimonial_section_enable( $control ) && ( 'custom' == $content_type );
}

/**
 * Check if skills section is enabled.
 *
 * @since Myself Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function myself_pro_is_skills_section_enable( $control ) {
	return ( $control->manager->get_setting( 'myself_pro_theme_options[skills_section_enable]' )->value() );
}

/**
 * Check if skills section content type is post.
 *
 * @since Myself Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function myself_pro_is_skills_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'myself_pro_theme_options[skills_content_type]' )->value();
	return myself_pro_is_skills_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if skills section content type is page.
 *
 * @since Myself Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function myself_pro_is_skills_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'myself_pro_theme_options[skills_content_type]' )->value();
	return myself_pro_is_skills_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if skills section content type is custom.
 *
 * @since Myself Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function myself_pro_is_skills_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'myself_pro_theme_options[skills_content_type]' )->value();
	return myself_pro_is_skills_section_enable( $control ) && ( 'custom' == $content_type );
}

/**
 * Check if blog section is enabled.
 *
 * @since Myself Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function myself_pro_is_blog_section_enable( $control ) {
	return ( $control->manager->get_setting( 'myself_pro_theme_options[blog_section_enable]' )->value() );
}

/**
 * Check if blog section content type is post.
 *
 * @since Myself Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function myself_pro_is_blog_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'myself_pro_theme_options[blog_content_type]' )->value();
	return myself_pro_is_blog_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if blog section content type is page.
 *
 * @since Myself Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function myself_pro_is_blog_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'myself_pro_theme_options[blog_content_type]' )->value();
	return myself_pro_is_blog_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if blog section content type is category.
 *
 * @since Myself Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function myself_pro_is_blog_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'myself_pro_theme_options[blog_content_type]' )->value();
	return myself_pro_is_blog_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if blog section content type is recent.
 *
 * @since Myself Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function myself_pro_is_blog_section_content_recent_enable( $control ) {
	$content_type = $control->manager->get_setting( 'myself_pro_theme_options[blog_content_type]' )->value();
	return myself_pro_is_blog_section_enable( $control ) && ( 'recent' == $content_type );
}

/**
 * Check if contact section is enabled.
 *
 * @since Myself Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function myself_pro_is_contact_section_enable( $control ) {
	return ( $control->manager->get_setting( 'myself_pro_theme_options[contact_section_enable]' )->value() );
}

/**
 * Check if cta section is enabled.
 *
 * @since Myself Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function myself_pro_is_cta_section_enable( $control ) {
	return ( $control->manager->get_setting( 'myself_pro_theme_options[cta_section_enable]' )->value() );
}

/**
 * Check if cta section content type is post.
 *
 * @since Myself Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function myself_pro_is_cta_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'myself_pro_theme_options[cta_content_type]' )->value();
	return myself_pro_is_cta_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if cta section content type is page.
 *
 * @since Myself Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function myself_pro_is_cta_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'myself_pro_theme_options[cta_content_type]' )->value();
	return myself_pro_is_cta_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if cta section content type is custom.
 *
 * @since Myself Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function myself_pro_is_cta_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'myself_pro_theme_options[cta_content_type]' )->value();
	return myself_pro_is_cta_section_enable( $control ) && ( 'custom' == $content_type );
}
